@@ -39,26 +39,9 @@ void checksum_block(char *buf, int len, unsigned char *digest);
 struct running_checksum;
 struct running_checksum *start_running_checksum(void);
 void add_to_running_checksum(struct running_checksum *c,
-			     unsigned int len, unsigned char *buf);
+			     unsigned char *buf, unsigned int len);
 void finish_running_checksum(struct running_checksum *c, unsigned char *digest);
 
-/* csum-module implementation details */
-
-struct csum_module_ops {
-	void (*checksum_block)(char *buf, int len, unsigned char *digest);
-	struct running_checksum *(*start_running_checksum)(void);
-	void (*add_to_running_checksum)(struct running_checksum *c,
-					unsigned int len, unsigned char *buf);
-	void (*finish_running_checksum)(struct running_checksum *c,
-					unsigned char *digest);
-};
-
-struct csum_module {
-	struct csum_module_ops *ops;
-};
-
-extern struct csum_module csum_module_xxhash;
-
 #define	DECLARE_RUNNING_CSUM_CAST_FUNCS(_type)				\
 static inline struct _type *						\
 rc_to_priv(struct running_checksum *rc)					\
